@@ -127,13 +127,13 @@ class select_geoms:
                     design_plot.crs = {'init': 'epsg:4326'}
                 design_plot = design_plot.to_crs({'init': 'epsg:4326'})
                 check_topology(design_plot)
-                self.TestPlot = design_plot
+                self.geodesign = design_plot
             else:
                 check_topology(design_plot).topology
-                self.TestPlot = design_plot
+                self.geodesign = design_plot
         except AttributeError:
             sg.Popup("     Side length of the test plot is larger than required, wont have any Test plot for the AOI,\n     because test plot threshold length is bigger,\n\n     Please insert smaller length for the Test Plots")
-            self.geosolution = None
+            self.geodesign = None
             pass
 
 class rotate_plot:
@@ -166,7 +166,7 @@ class rotate_plot:
                 del self.plot['geometry']
                 self.plot.rename(columns={"rotate": "geometry"}, inplace = True)
                 self.plot.set_geometry(col = 'geometry', inplace = True)
-                self.rotate = self.plot
+                self.geodesign = self.plot
             else:
                 pass
         else:
@@ -253,4 +253,4 @@ class check_topology:
                 val_data = val_data.append(val)
         if val_data.crs == None:
             val_data.crs = {'init': 'epsg:4326'}
-        self.geosolution = val_data
\ No newline at end of file
+        self.geodesign = val_data
\ No newline at end of file
